/// <reference types="cheerio" />
import { BoxrecRole } from 'boxrec-requests';
import { BoutsInterface } from '../../decorators/bouts.decorator';
import { BoxrecBasic, BoxrecBoutLocation, BoxrecLocation } from '../boxrec.constants';
import { BoxrecPageEventBoutRow } from './boxrec.page.event.bout.row';
import { BoxrecParseBouts } from './boxrec.parse.bouts';
/**
 * Used specifically for Events page and Dates page
 */
export declare abstract class BoxrecEvent extends BoxrecParseBouts implements BoutsInterface {
    bouts: BoxrecPageEventBoutRow[];
    protected static getVenueInformation(links: Cheerio): BoxrecBasic;
    protected static getLocationInformation(links: Cheerio): BoxrecLocation;
    get location(): BoxrecBoutLocation;
    /**
     * The order of returned matchmakers can change
     */
    get matchmakers(): BoxrecBasic[];
    get promoters(): BoxrecBasic[];
    /**
     * Returns contact information on how to buy tickets for this event
     * example: boxrec.com/en/date?ByV%5Bdate%5D%5Byear%5D=2019&ByV%5Bdate%5D%5Bmonth%5D=11&ByV%5Bdate%5D%5Bday%5D=16
     */
    get tickets(): string | null;
    protected getPeopleTable(): Cheerio;
    protected parseEventData(role: BoxrecRole | 'media' | 'commission' | 'tickets', parseHTML?: boolean): string;
    protected parseLocation(): string | null;
    protected parseMatchmakers(): string;
    protected parsePromoters(): string;
}
