import { ListingsInterface } from '../../decorators/listings.decorator';
import { OutputInterface } from '../../decorators/output.decorator';
import { BoxrecLocation } from '../boxrec.constants';
import { BoxrecVenueOutput } from './boxrec.page.venue.constants';
import { BoxrecPageVenueEventsRow } from './boxrec.page.venue.events.row';
/**
 * parse a BoxRec Venue page
 * <pre>ex. http://boxrec.com/en/venue/38555</pre>
 */
export declare class BoxrecPageVenue implements ListingsInterface, OutputInterface {
    output: BoxrecVenueOutput;
    /**
     * Returns an array of events
     * @returns {BoxrecPageVenueEventsRow[]} is in order of the page events may have been inserted into BoxRec and
     * the IDs will not always be in order
     */
    events: BoxrecPageVenueEventsRow[];
    private readonly $;
    constructor(boxrecBodyString: string);
    /**
     * Returns an array of boxers that are in the area
     * @returns {Object}  could use BoxrecBasic but this shouldn't return null values, so using `{ id: string, name: string }[]`
     */
    get localBoxers(): Array<{
        id: number;
        name: string;
    }>;
    /**
     * Returns an array of managers that operate in this area
     * @returns {Object}  could use BoxRecBasic but this shouldn't return null values, so using `{ id: string, name: string }[]`
     */
    get localManagers(): Array<{
        id: number;
        name: string;
    }>;
    get location(): BoxrecLocation;
    get name(): string;
    private parseBasicInfo;
}
